package com.zkqy.system.service;

import java.util.List;

import com.zkqy.system.entity.DragFormGroup;

/**
 * 动态表单组Service接口
 *
 * @author hzh
 * @date 2024-01-26
 */
public interface IDragFormGroupService {
    /**
     * 查询动态表单组
     *
     * @param id 动态表单组主键
     * @return 动态表单组
     */
    public DragFormGroup selectDragFormGroupById(Long id);

    /**
     * 查询动态表单组
     *
     * @param groupKey 动态表单组编码
     * @return 动态表单组
     */
    public DragFormGroup selectDragFormGroupByGroupKey(String groupKey);

    /**
     * 查询动态表单组列表
     *
     * @param dragFormGroup 动态表单组
     * @return 动态表单组集合
     */
    public List<DragFormGroup> selectDragFormGroupList(DragFormGroup dragFormGroup);

    /**
     * 新增动态表单组
     *
     * @param dragFormGroup 动态表单组
     * @return 结果
     */
    public int insertDragFormGroup(DragFormGroup dragFormGroup);

    /**
     * 修改动态表单组
     *
     * @param dragFormGroup 动态表单组
     * @return 结果
     */
    public int updateDragFormGroup(DragFormGroup dragFormGroup);

    /**
     * 批量删除动态表单组
     *
     * @param ids 需要删除的动态表单组主键集合
     * @return 结果
     */
    public int deleteDragFormGroupByIds(Long[] ids);

    /**
     * 删除动态表单组信息
     *
     * @param id 动态表单组主键
     * @return 结果
     */
    public int deleteDragFormGroupById(Long id);
}
